# Generated by Django 3.1 on 2020-10-09 00:00

from django.db import migrations, models
import multiselectfield.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('helpme', '0009_auto_20201001_1913'),
    ]

    operations = [
        migrations.AlterField(
            model_name='category',
            name='category',
            field=models.CharField(max_length=120, verbose_name='Category'),
        ),
        migrations.AlterField(
            model_name='question',
            name='answer',
            field=models.CharField(max_length=255, verbose_name='Answer'),
        ),
        migrations.AlterField(
            model_name='question',
            name='question',
            field=models.CharField(max_length=120, verbose_name='Question'),
        ),
        migrations.AlterField(
            model_name='team',
            name='categories',
            field=multiselectfield.db.fields.MultiSelectField(choices=[(1, 'Comment'), (2, 'Sales'), (3, 'Help'), (4, 'Bug')], max_length=7, verbose_name='Categories'),
        ),
        migrations.AlterField(
            model_name='team',
            name='name',
            field=models.CharField(max_length=30, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='ticket',
            name='dev_ticket',
            field=models.CharField(blank=True, max_length=30, null=True, verbose_name='Developer Ticket'),
        ),
    ]
