# Generated by Django 3.1 on 2020-09-01 23:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('helpme', '0003_auto_20200901_2025'),
    ]

    operations = [
        migrations.AlterField(
            model_name='category',
            name='sites',
            field=models.ManyToManyField(blank=True, related_name='categories', to='sites.Site'),
        ),
    ]
