# Generated by Django 3.1 on 2020-10-01 19:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('helpme', '0008_auto_20200930_2347'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='ticket',
            options={'permissions': (('see_support_tickets', 'Access to support-level tickets'), ('see_developer_tickets', 'Access to developer-level tickets'), ('see_all_tickets', 'Access to all tickets'))},
        ),
    ]
