# Generated by Django 3.1 on 2020-09-01 20:25

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('sites', '0002_alter_domain_unique'),
        ('helpme', '0002_category_question'),
    ]

    operations = [
        migrations.AddField(
            model_name='category',
            name='excluded_sites',
            field=models.ManyToManyField(blank=True, related_name='excluded_categories', to='sites.Site'),
        ),
        migrations.AddField(
            model_name='category',
            name='global_category',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='question',
            name='excluded_sites',
            field=models.ManyToManyField(blank=True, related_name='excluded_questions', to='sites.Site'),
        ),
        migrations.AddField(
            model_name='question',
            name='global_question',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='ticket',
            name='question',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='helpme.question'),
        ),
        migrations.AlterField(
            model_name='category',
            name='sites',
            field=models.ManyToManyField(related_name='categories', to='sites.Site'),
        ),
        migrations.AlterField(
            model_name='question',
            name='sites',
            field=models.ManyToManyField(blank=True, related_name='questions', to='sites.Site'),
        ),
    ]
