# Generated by Django 3.1 on 2020-09-30 23:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('helpme', '0007_auto_20200912_0509'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='category',
            options={'verbose_name_plural': 'Categories'},
        ),
    ]
